==> com.liferay.exportimport.service-3.2.2-sources.jar: com/liferay/exportimport/lar/PortletDataContextListenerImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.exportimport.lar;

import com.liferay.exportimport.kernel.lar.PortletDataContext;
import com.liferay.exportimport.kernel.lar.PortletDataContextListener;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;

/**
 * @author     Raymond Augé
 * @deprecated As of 3.0.0, see {@link
 *             com.liferay.exportimport.kernel.lifecycle.ExportImportLifecycleEvent}
 */
@Deprecated
public class PortletDataContextListenerImpl
	implements PortletDataContextListener {

	public PortletDataContextListenerImpl(
		PortletDataContext portletDataContext) {
	}

	@Override
	public void onAddZipEntry(String path) {
		if (_log.isInfoEnabled()) {
			_log.info("Export " + path);
		}
	}

	@Override
	public void onGetZipEntry(String path) {
		if (_log.isInfoEnabled()) {
			_log.info("Import " + path);
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		PortletDataContextListenerImpl.class);

}

==> com.liferay.exportimport.service-4.1.10-sources.jar: com/liferay/exportimport/lar/PortletDataContextListenerImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.exportimport.lar;

import com.liferay.exportimport.kernel.lar.PortletDataContext;
import com.liferay.exportimport.kernel.lar.PortletDataContextListener;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;

/**
 * @author     Raymond Augé
 * @deprecated As of Wilberforce (7.0.x), see {@link
 *             com.liferay.exportimport.kernel.lifecycle.ExportImportLifecycleEvent}
 */
@Deprecated
public class PortletDataContextListenerImpl
	implements PortletDataContextListener {

	public PortletDataContextListenerImpl(
		PortletDataContext portletDataContext) {
	}

	@Override
	public void onAddZipEntry(String path) {
		if (_log.isInfoEnabled()) {
			_log.info("Export " + path);
		}
	}

	@Override
	public void onGetZipEntry(String path) {
		if (_log.isInfoEnabled()) {
			_log.info("Import " + path);
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		PortletDataContextListenerImpl.class);

}
